@@ -6,6 +6,7 @@ from urge import procs
 from urge.base import Action, action
 from urge.procs import weather, youdao, browser, memegen, fileoperation
 from dataclasses import dataclass
+from path import Path
 
 
 class do(Action):
@@ -132,8 +133,9 @@ class find:
     def rename(self, with_suffix: str = None, with_preafix: str = None):
         return locals()
 
-    def zip(self):
-        ...
+    @action([fileoperation._zip_files])
+    def zip(self, with_folder=False):
+        return dict(f_list=self._list, with_folder=with_folder)
 
     @action([fileoperation])
     def unzip(self):
