@@ -1,6 +1,9 @@
 import httpx
 from pyquery import PyQuery
-from ..base import ProcManager
+from urge.base import ProcManager
+import typing as t
+
+# from ..base import ProcManager
 
 
 def get_weather(city, ascii_graphs: bool = True, lang: str = "en", **kwargs) -> dict:
@@ -10,13 +13,15 @@ def get_weather(city, ascii_graphs: bool = True, lang: str = "en", **kwargs) ->
     return dict(res=res, ascii_graphs=ascii_graphs)
 
 
-def ret_weather(res: httpx.Response, ascii_graphs: bool, **kwargs) -> str:
+def ret_weather(
+    res: httpx.Response, ascii_graphs: bool, **kwargs
+) -> t.Union[str, float]:
     if ascii_graphs:
         pq = PyQuery(res.text)
         result = pq.find('pre')
         return str(result.text(squash_space=False))
     temp = res.json().get('current_condition')
-    return temp[0].get('FeelsLikeC')
+    return float(temp[0].get('FeelsLikeC'))
 
 
 def get_now_temp(city: str, ascii_graphs: bool = True):
@@ -25,4 +30,4 @@ def get_now_temp(city: str, ascii_graphs: bool = True):
 
 
 def get_simple_temp(city: str):
-    return get_now_temp(city, ascii_graphs=False)
+    return int(get_now_temp(city, ascii_graphs=False))
